@@ -17,7 +17,7 @@ class API():
         return urljoin(self.base, self.path)
 
     def make_call(self, path, params, retry=1):
-        print(f'Making url call retry ={retry}')
+        # print(f'Making url call retry ={retry}')
         limit = 5
         headers = {
             'Ocp-Apim-Subscription-Key': self.subscription.Auth.primary_key,
@@ -118,6 +118,26 @@ class AgenyIncidentsApi(API):
         else:
             raise WebCallException
 
+    def get_all_exposure_apparatuses(self, **kwargs):
+        path = 'exposures/apparatuses'
+        response = self.make_call(path, kwargs)
+        if response.ok:
+            return response.json()['exposureApparatuses']
+        else:
+            raise WebCallException    
+
+class AgencyApparatusApi(API):
+
+    def __init__(self, subscription):
+        super().__init__('Ageny Apparatus', 'agencyapparatus/', subscription=subscription)
+
+    def get_apparatuses(self, **kwargs):
+        path = 'apparatus'
+        response = self.make_call(path, kwargs)
+        if response.ok:
+            return response.json()['apparatus']
+        else:
+            raise WebCallException
 
 class AgencyUsersApi(API):
 
